Version 0.5.0
------------

Released on Jun 3rd 2018

- Fix MANIFEST.in
- Fix Flake8 errors

Version 0.4.0
------------

Released on May 23th 2018

- Add Flake8
- Fix MANIFEST.in

Version 0.3.0
------------

Released on Aug 9th 2014

- Add requests and mock to test_require
- Remove unused argparse requirement

Version 0.2
-----------

Released on January 26th 2014

- Fixed broken running Py.Test and Python2.7.


Version 0.1
-----------

Released on January 25th 2014

- First public preview release.
